function [Actions, Basisfunctions, reward, Z] = createSampleStepsTwoArms(W,M,tau, Latent,DimPerGroup,Time,draw)
%createSampleStepsTwoArms Create a sample for the two arms simulation


    DoF = sum(DimPerGroup);
    
    if DoF ~= 12
        warning('Experiment is designed for 12 DoF. The number of DoF is not equal 12. Possible error!');
    end
    if DoF < 7
        error('Experiment requires at least 7 DoF.');
    end

    nmbrOfGroups = length(DimPerGroup);
    
    x = 4 - (1:Time)./Time * 4;
    y = 4 * ones(1,Time);
    x2 = -x;

    % Create the basic functions
    means = (-3):3:(Time+3);
    BasisDim = length(means);
    variance = 3;
    featureFun = @(t) cell2mat(arrayfun(@(t_i) normpdf(t_i,means,variance)',t,'UniformOutput',0));
    Basisfunctions = featureFun(1:Time);
    Basisfunctions = Basisfunctions ./ repmat(sum(Basisfunctions),BasisDim,1);
    Z = randn(Latent,BasisDim);
    
    Actions = zeros(DoF,Time);

    
    for t=1:Time
        for m=1:nmbrOfGroups
            startDim = 1 + sum(DimPerGroup(1:(m-1)));
            Actions(startDim:(startDim + DimPerGroup(m) - 1),t) = ...
                W{m} * Z * Basisfunctions(:,t) + ...
                M{m} * Basisfunctions(:,t) + ...
                normrnd(0,inv(tau{m})+2, DimPerGroup(m), BasisDim) * Basisfunctions(:,t);
        end
    end
    
    reward = zeros(1,Time);
    for t=1:Time
        CurrentAngle = Actions(:,t);
        position = calcEndeffektor(CurrentAngle(1:6)');
        position2 = calcEndeffektor(CurrentAngle(7:end)');
        if sum(abs(CurrentAngle) > 180)
            reward(t) = 10^100000;
        else
            reward(t) = max(norm([x(t) y(t)] - position(1:2)',2),0);
            reward(t) = reward(t) + max(norm([x2(t) y(t)] - position2(1:2)',2),0);
        end
%         if draw
%             drawRoboTwoArms(CurrentAngle(1:6)',CurrentAngle(7:end)', [x(t) y(t) 0], [x2(t) y(t) 0]);
%             drawnow;
%             pause(0.1);
%         end
    end
    reward2 = exp(-reward);
    
    reward = ones(size(reward2)) * sum(reward2);
    
    Z = Z*Basisfunctions;
end

